@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11601 2019-06-01 19:27:05Z Lavender $
+# $Id: views.py 11629 2019-06-11 17:44:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-02 04:27:05 +0900 (週日, 02 六月 2019) $
-# $Revision: 11601 $
+# $Date: 2019-06-12 01:44:34 +0800 (週三, 12 六月 2019) $
+# $Revision: 11629 $
 
 import json
 import six
@@ -32,8 +32,6 @@ from django.shortcuts import redirect, get_object_or_404
 from django.contrib.auth import get_user_model
 
 from Iuppiter.Encoding import utf8
-from Zephyrus.facebook import settings as FBSettings
-from Zephyrus.facebook import getCommentURL
 from Zephyrus.comment.models import Comment, CommentPlugin
 from Zephyrus.comment.forms import CommentForm
 
@@ -127,44 +125,4 @@ class CommentHideView(View):
             comment.display = False
             comment.save()
         return redirect(comment.url)
-
-class CommentWebHookView(View):
-    def get(self, request, *args, **kwargs):
-        verify = request.GET.get('hub.verify_token')
-        if verify == FBSettings.ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN:
-            return HttpResponse(request.GET.get('hub.challenge'))
-        else:
-            return HttpResponse('Error, invalid token')
-        
-    @method_decorator(csrf_exempt)
-    def dispatch(self, request, *args, **kwargs):
-        return super(
-            CommentWebHookView, self).dispatch(request, *args, **kwargs)
-
-    def post(self, request, *args, **kwargs):
-        msg = request.body.decode('utf-8')
-        
-        data = json.loads(msg)
-
-        entry = data.get("entry")
-        if entry:
-            for e in entry:
-                changes = e.get("changes")
-                if changes:
-                    for c in changes:
-                        field = c.get("field")
-                        message = c.get("value", {}).get("message")
-                        mid = c.get("value", {}).get("id")
-                        name = c.get("value", {}).get("from", {}).get("name")
-                        if field == "plugin_comment":
-                            url = getCommentURL(mid)
-                            comment = Comment.objects.create(
-                                url=url,
-                                message=message,
-                                facebook=True,
-                                facebookMsgId=str(mid),
-                                facebookUser=name,
-                            )
-   
-        return HttpResponse('Success')
         
\ No newline at end of file
